# Generated by roxygen2: do not edit by hand

S3method(apply_scale,default)
S3method(apply_scale,gt_group)
S3method(apply_scale,gt_tbl)
S3method(apply_scale,list)
S3method(fancywrap,default)
S3method(fancywrap,docorator)
S3method(fancywrap,fancyfoot)
S3method(fancywrap,fancyhead)
S3method(fancywrap,fancyrow)
S3method(hf_height,default)
S3method(hf_height,fancyhdr)
S3method(hf_process,character)
S3method(hf_process,default)
S3method(hf_process,fancyfoot)
S3method(hf_process,fancyhead)
S3method(prep_obj_docx,PNG)
S3method(prep_obj_docx,default)
S3method(prep_obj_docx,gt_tbl)
S3method(prep_obj_docx,list)
S3method(prep_obj_rtf,PNG)
S3method(prep_obj_rtf,character)
S3method(prep_obj_rtf,default)
S3method(prep_obj_rtf,ggplot)
S3method(prep_obj_rtf,gt_tbl)
S3method(prep_obj_rtf,list)
S3method(prep_obj_tex,PNG)
S3method(prep_obj_tex,character)
S3method(prep_obj_tex,default)
S3method(prep_obj_tex,gt_tbl)
export(apply_scale)
export(apply_to_gt_group)
export(as_docorator)
export(create_chunks_all)
export(doc_datetime)
export(doc_pagenum)
export(doc_path)
export(docorate)
export(fancyfoot)
export(fancyhead)
export(fancyrow)
export(geom_set)
export(hf_extract)
export(hf_height)
export(hf_process)
export(hf_to_gt)
export(png_path)
export(prep_obj_docx)
export(prep_obj_rtf)
export(prep_obj_tex)
export(render_docx)
export(render_pdf)
export(render_rtf)
export(scale_gt)
importFrom(rlang,`%||%`)
