---
output:
  pdf_document:
    latex_engine: xelatex
    keep_tex:  false  
classoption: landscape
params:
  x: NULL 
  header: NULL
  footer: NULL
  geometry: NULL
  transform: NULL
fontsize: "`r paste0(params$x$fontsize, 'pt')`"
geometry: "`r params$geometry`" 
header-includes:  
  - \renewcommand*\familydefault{\ttdefault}
  - \usepackage{fancyhdr, lastpage}
  - \usepackage{booktabs, longtable, colortbl, array, multirow, anyfontsize}
  - \usepackage[labelformat=empty]{caption} 
  - \IfFileExists{header.tex}{\input{header.tex}}{}
fig_crop: FALSE
---

<!--- Define Headers and Footers --->
```{=tex}
\fancypagestyle{plain}{
  \renewcommand{\headrulewidth}{0pt}
  \fancyhf{}%
  `r params$header`
  `r params$footer`
}
\pagestyle{plain} 
```
 
\centering


```{r echo = FALSE, results = "asis"}
create_chunks_all(params$x, params$transform)
```


