# gt to latex conversion preserves formatting

    Code
      preamble[1:6]
    Output
      [1] "\\begingroup"                                                                                                                      
      [2] "\\fontsize{10.0pt}{13.0pt}\\selectfont"                                                                                            
      [3] "\\begin{longtable}{llll}"                                                                                                          
      [4] "\\toprule"                                                                                                                         
      [5] " & \\multicolumn{1}{c}{{Placebo}} & \\multicolumn{1}{c}{{Xanomeline Low Dose}} & \\multicolumn{1}{c}{{Xanomeline High Dose}} \\\\ "
      [6] "\\midrule\\endhead\\addlinespace[2.5pt]"                                                                                           

