# geometry processing - docx

    Code
      geom <- geom_process(geometry = geom_set(left = "1.27cm"), engine = "docx")
    Message
      Geometry value "1.27cm" changed to 1.27 inches for docx output

---

    Code
      geom <- geom_process(geometry = list(left = "1.27in"), engine = "docx")
    Message
      Geometry values for "right", "top", and "bottom" are not specified. Using
      defaults from geom_set()

